<?php

namespace Munisense\Zigbee\ZDP\Discovery;
use Munisense\Zigbee\AbstractFrame;
use Munisense\Zigbee\Buffer;
use Munisense\Zigbee\Exception\ZigbeeException;
use Munisense\Zigbee\ZDP\Command;
use Munisense\Zigbee\ZDP\IZDPCommandFrame;
use Munisense\Zigbee\ZDP\Status;

/**
 * Class UserDescConfCommand
 * @package Munisense\Zigbee\ZDP\Discovery
 *
 * The Simple_Desc_rsp is generated by a remote device in response to a
 * Simple_Desc_req directed to the remote device.
 */
class UserDescConfCommand extends AbstractFrame implements IZDPCommandFrame
  {
  private static $allowed_statusses = [Status::SUCCESS, Status::NOT_SUPPORTED,
                                       Status::DEVICE_NOT_FOUND, Status::INV_REQUESTTYPE, Status::NO_DESCRIPTOR];

  private $status;
  private $nwk_addr_of_interest;

  public static function construct($status, $nwk_addr_of_interest)
    {
    $frame = new self;
    $frame->setStatus($status);
    $frame->setNwkAddrOfInterest($nwk_addr_of_interest);
    return $frame;
    }

  public function setFrame($frame)
    {
    $this->setStatus(Buffer::unpackInt8u($frame));
    $this->setNwkAddrOfInterest(Buffer::unpackInt16u($frame));
    }

  public function getFrame()
    {
    $frame = "";

    Buffer::packInt8u($frame, $this->getStatus());
    Buffer::packInt16u($frame, $this->getNwkAddrOfInterest());

    return $frame;
    }

  /**
   * @return int
   */
  public function getStatus()
    {
    return $this->status;
    }

  /**
   * @param $status
   * @throws \Munisense\Zigbee\Exception\ZigbeeException
   */
  public function setStatus($status)
    {
    if(in_array($status, self::$allowed_statusses))
      $this->status = $status;
    else
      throw new ZigbeeException("Invalid status supplied");
    }

  public function displayStatus()
    {
    return Status::displayStatus($this->getStatus());
    }

  /**
   * @return array
   */
  public static function getAllowedStatusses()
    {
    return self::$allowed_statusses;
    }

  /**
   * @param array $allowed_statusses
   */
  public static function setAllowedStatusses($allowed_statusses)
    {
    self::$allowed_statusses = $allowed_statusses;
    }

  /**
   * @return int
   */
  public function getNwkAddrOfInterest()
    {
    return $this->nwk_addr_of_interest;
    }

  /**
   * @param $nwk_address
   * @throws \Munisense\Zigbee\Exception\ZigbeeException
   */
  public function setNwkAddrOfInterest($nwk_address)
    {
    if($nwk_address >= 0x0000 && $nwk_address <= 0xffff)
      $this->nwk_addr_of_interest = $nwk_address;
    else
      throw new ZigbeeException("Invalid nwk address");
    }

  public function displayNwkAddrOfInterest()
    {
    return Buffer::displayInt16u($this->getNwkAddrOfInterest());
    }

  public function __toString()
    {
    $output = __CLASS__." (length: ".strlen($this->getFrame()).")".PHP_EOL;
    $output .= "|- Status    : ".$this->displayStatus().PHP_EOL;
    $output .= "|- NwkAddr   : ".$this->displayNwkAddrOfInterest().PHP_EOL;

    return $output;
    }

  /**
   * Returns the Cluster ID of this frame
   *
   * @return int
   */
  public function getClusterId()
    {
    return Command::COMMAND_USER_DESC_CONF;
    }
  }

